// special variables positioned by the vertex shader
varying vec3 normal;        // global variable normal vector
varying vec3 light;         // global variable light vector
varying vec2 texcoords;     // texture coordinates

const float Strenght = 0.9;

uniform sampler2D Texture; 

void main()
{
    // diffuse and ambient colors
    const vec4 Ka = vec4(0.1, 0.0, 0.0, 1.0);
    const vec4 Kd = vec4(0.4, 0.4, 0.8, 1.0);
    
    // calculate the value of the bump there (x2 magnification of the texture)
    vec3 bump = vec3(texture2D(Texture, 2.0*texcoords));
    vec3 disruption = (bump + vec3(-0.5,-0.5,-0.5)) * Strenght;
    
    // disrupt the normal
    vec3 normle = normalize(normal + disruption);
    
    // calculate the formula of Lambert and preventing overruns
    float scalarProduct = clamp(dot(normle, light), 0.0, 1.0);
    
    // calculate the final color and simulate a diffuse specular term a little tin
    // Normally, we calculate the specular reflection with the reflection of the view
    gl_FragColor = Ka + Kd * scalarProduct + 0.9*pow(scalarProduct, 10.0);
}