uniform sampler2D depthMap;
uniform sampler2D colorTex;
uniform vec3 lightPosition[3];
uniform vec3 lightColor[3];
uniform float power; //power of direct translucency 
uniform float scale; //how big the light effect on surface should be
uniform float distortion; //subsurface distortion
uniform float ambient;
uniform vec3 diffuse;
uniform float shininess;
uniform vec2 viewport;

uniform float kC;
uniform float kL;
uniform float kQ;
uniform float specScale;

varying vec3 worldPos;
varying vec3 eyeDir;
varying vec3 lightDir[3];
varying vec3 normal;
varying float height;

void main()
{
	vec4 FinalColor = texture2D(colorTex, vec2(height, 0.5));//vec4(0.0, 0.0, 0.0, 1.0);//

	vec4 vAmbient = vec4(0.0, 0.0, 0.0, 1.0);
	vec4 vDiffuse = vec4(diffuse, 1.0);		

	vec4 thickness = texture2D(depthMap, vec2(gl_FragCoord.x/viewport.x, gl_FragCoord.y/viewport.y));
		
	vec3 N = normalize(normal);
	vec3 V = normalize(eyeDir);
				
	FinalColor.rgb += vAmbient.rgb;

	for( int i=0; i<3; i++ )
	{
		vec3 L = normalize(lightDir[i]);
				
		float d = length(lightPosition[i] - worldPos);
		float LightAttenuation = (1.0 / (kC + kL*d + kQ*d*d));

		//translucency
		vec3 light = normalize(L + (N * distortion));
		float ddot = pow(clamp(dot(V, -light), 0.0, 1.0), power) * scale;
		vec3 LT = LightAttenuation * (ddot + ambient) * thickness.rgb;
		
		// Blinn lighting
		float NdotL = max(dot(N, L), 0.0);
					
		vec3 diffcomp = vDiffuse.rgb * lightColor[i] * NdotL;
		diffcomp = clamp(diffcomp, 0.0, 1.0);
		vec3 H = normalize(V + L);			
		vec3 specular = vec3(clamp(specScale*pow( max(dot(N, H), 0.0), shininess), 0.0, 1.0));

		FinalColor.rgb += (diffcomp + specular) * LightAttenuation;
		FinalColor.rgb += vDiffuse.rgb * lightColor[i] * LT;
	}

	FinalColor.rgb = clamp(FinalColor.rgb, 0.0, 1.0);
	gl_FragColor = FinalColor;
}